@@ -64,7 +64,7 @@ Available objects in the package
 
 While different objects are defined in the source at different levels (e.g. the
 Nim class in the source/core.py module), the necessary ones are made available
-at the package level, i.e. after importing nimgame, the nimgame.Nim refers to
+at the package level, i.e. after importing nimgame, the `nimgame.Nim` refers to
 that class.
 
 Nim
@@ -90,19 +90,25 @@ HeapCoinRange
 Package content
 ===============
 
-source/core
-    It provides the Nim class and its public methods
-source/calculations
-    A mixin of the Nim class with calculation methods
-modules in "source/playing"
+:mod:`core`
+    It provides the :class:`core.Nim` class and its public methods
+
+:mod:`calculations`
+    A mixin of the :class:`core.Nim` class with calculation methods
+
+modules in "playing"
     Functions to play the game. E.g. demo.py can be run to do interactions for
     executing automatic runs or interactive games. The same is executed when
     
     -   the package itself is called (see the "__main__.py" module), e.g.
+    
         :command:`python -m nimgame`
-    -   the :command:`nimgame.exe` (in Scripts) is executed. NB, the python
-        Scripts dir is usually in the execution path, i.e. the nimgame.exe should
-        be available from anywhere in the CLI prompt.
+        
+    -   the :command:`nimgame.exe` (in Scripts) is executed.
+        
+        NB, the python Scripts dir is usually in the execution path, i.e. the
+        nimgame.exe should be available from anywhere in the CLI prompt.
+
 modules in "tests"
     You can test the function by running several games automatically and gather
     statistics.
@@ -112,8 +118,8 @@ modules in "tests"
 .. _misère: https://en.wikipedia.org/wiki/Mis%C3%A8re#Mis%C3%A8re_game
 """
 # Make sure the package base path is in the module import path (e.g. for flit)
-import sys, os
-basepath = os.path.dirname(__file__)
+import sys, pathlib
+basepath = str(pathlib.PurePath(__file__).parent)
 if basepath not in sys.path:
     sys.path.insert(0, basepath)
 
