@@ -10,11 +10,11 @@
 # add these directories to sys.path here. If the directory is relative to the
 # documentation root, use os.path.abspath to make it absolute, like shown here.
 #
-import os
-import sys
-sys.path.insert(0, os.path.abspath('../source'))
-sys.path.insert(0, os.path.abspath('..'))
-
+# Insert the package path first, so that the package __init__ is found first
+# before the source/__init__ module
+import sys, pathlib
+sys.path.insert(0, str(pathlib.Path('..').resolve()))
+sys.path.insert(1, str(pathlib.Path('../source').resolve()))
 
 # -- Project information -----------------------------------------------------
 
