@@ -1,4 +1,8 @@
-"""ANSI codes for manipulating console display"""
+"""ANSI codes for manipulating console display
+
+These functions are used for cleaning lines after an input is taken or an error
+is displayed.
+"""
 
 
 # An empty command seems to make the Windows cmd terminal capable of ANSI.
@@ -20,7 +24,7 @@ def clean_this_line():
 
 
 def clean_prev_line():
-    """Clean the input prompt and answer"""
+    """Clean the input prompt and the answer"""
     print(
         CURSOR_UP + DELETE_LINE, 
         end='' #supress line feed
